import { EventEmitter } from '@angular/core';
import { Observable } from 'rxjs';
import { ODataActionOptions, ODataEntitiesAnnotations, ODataEntitySetResource, ODataFunctionOptions, ODataNavigationPropertyResource, ODataOptions, ODataPropertyResource, ODataQueryOptionsHandler, ODataResource } from '../resources';
import { ODataStructuredType } from '../schema/structured-type';
import { ODataModel } from './model';
import { ModelFieldOptions, ODataModelEntry, ODataModelEvent, ODataModelField } from './options';
export declare class ODataCollection<T, M extends ODataModel<T>> implements Iterable<M> {
    static model: typeof ODataModel | null;
    _parent: [
        ODataModel<any> | ODataCollection<any, ODataModel<any>>,
        ODataModelField<any> | null
    ] | null;
    _resource: ODataEntitySetResource<T> | ODataNavigationPropertyResource<T> | ODataPropertyResource<T> | null;
    _resources: {
        parent: [
            ODataModel<any> | ODataCollection<any, ODataModel<any>>,
            ODataModelField<any> | null
        ] | null;
        resource: ODataEntitySetResource<T> | ODataNavigationPropertyResource<T> | ODataPropertyResource<T> | null;
    }[];
    _annotations: ODataEntitiesAnnotations<T>;
    _entries: ODataModelEntry<T, M>[];
    _model: typeof ODataModel;
    models(): M[];
    get length(): number;
    events$: EventEmitter<ODataModelEvent<T>>;
    constructor(entities?: Partial<T>[] | {
        [name: string]: any;
    }[], { parent, resource, annots, model, reset, }?: {
        parent?: [ODataModel<any>, ODataModelField<any>];
        resource?: ODataResource<T>;
        annots?: ODataEntitiesAnnotations<T>;
        model?: typeof ODataModel;
        reset?: boolean;
    });
    isParentOf(child: ODataModel<any> | ODataCollection<any, ODataModel<any>>): boolean;
    resource(): ODataEntitySetResource<T> | ODataNavigationPropertyResource<T> | ODataPropertyResource<T>;
    pushResource(resource: ODataEntitySetResource<T> | ODataNavigationPropertyResource<T> | ODataPropertyResource<T>): void;
    popResource(): {
        parent: [ODataModel<any> | ODataCollection<any, ODataModel<any>>, ODataModelField<any> | null] | null;
        resource: ODataEntitySetResource<T> | ODataNavigationPropertyResource<T> | ODataPropertyResource<T> | null;
    } | undefined;
    attach(resource: ODataEntitySetResource<T> | ODataNavigationPropertyResource<T> | ODataPropertyResource<T>): void;
    withResource<R>(resource: ODataEntitySetResource<T> | ODataNavigationPropertyResource<T> | ODataPropertyResource<T>, ctx: (collection: this) => R): R;
    asEntitySet<R>(ctx: (collection: this) => R): R;
    annots(): ODataEntitiesAnnotations<T>;
    private modelFactory;
    toEntities({ client_id, include_navigation, include_concurrency, include_computed, include_key, include_non_field, changes_only, field_mapping, chain, }?: {
        client_id?: boolean;
        include_navigation?: boolean;
        include_concurrency?: boolean;
        include_computed?: boolean;
        include_key?: boolean;
        include_non_field?: boolean;
        changes_only?: boolean;
        field_mapping?: boolean;
        chain?: (ODataModel<any> | ODataCollection<any, ODataModel<any>>)[];
    }): (Partial<T> | {
        [name: string]: any;
    })[];
    toJSON(): (Partial<T> | {
        [name: string]: any;
    })[];
    hasChanged({ include_navigation }?: {
        include_navigation?: boolean;
    }): boolean;
    clone<C extends ODataCollection<T, M>>(): C;
    private _request;
    fetch({ withCount, remove, ...options }?: ODataOptions & {
        remove?: boolean;
        withCount?: boolean;
    }): Observable<M[]>;
    fetchAll({ withCount, remove, ...options }?: ODataOptions & {
        remove?: boolean;
        withCount?: boolean;
    }): Observable<M[]>;
    fetchMany(top: number, { withCount, remove, ...options }?: ODataOptions & {
        remove?: boolean;
        withCount?: boolean;
    }): Observable<M[]>;
    fetchOne({ withCount, remove, ...options }?: ODataOptions & {
        remove?: boolean;
        withCount?: boolean;
    }): Observable<M>;
    /**
     * Save all models in the collection
     * @param relModel The model is relationship
     * @param method The method to use
     * @param options HttpOptions
     */
    save({ relModel, method, ...options }?: ODataOptions & {
        relModel?: boolean;
        method?: 'update' | 'modify';
    }): Observable<this>;
    private addReference;
    private _addModel;
    private addModel;
    add(model: M, { silent, reparent, server, merge, position, }?: {
        silent?: boolean;
        reparent?: boolean;
        server?: boolean;
        merge?: boolean;
        position?: number;
    }): Observable<M>;
    private removeReference;
    private _removeModel;
    private removeModel;
    remove(model: M, { silent, server, }?: {
        silent?: boolean;
        server?: boolean;
    }): Observable<M>;
    private _moveModel;
    create(attrs?: T, { silent, server, }?: {
        silent?: boolean;
        server?: boolean;
    }): Observable<M>;
    set(path: string | string[], value: any, {}: {} & ModelFieldOptions): any;
    get(path: number): M | undefined;
    get(path: string | string[]): any;
    has(path: number | string | string[]): boolean;
    reset({ path, silent, }?: {
        path?: string | string[];
        silent?: boolean;
    }): void;
    clear({ silent }?: {
        silent?: boolean;
    }): void;
    assign(objects: Partial<T>[] | {
        [name: string]: any;
    }[] | M[], { remove, reset, reparent, silent, }?: {
        remove?: boolean;
        reset?: boolean;
        reparent?: boolean;
        silent?: boolean;
    }): void;
    query(ctx: (q: ODataQueryOptionsHandler<T>, s?: ODataStructuredType<T>) => void): this;
    callFunction<P, R>(name: string, params: P | null, responseType: 'property' | 'model' | 'collection' | 'none', { ...options }?: {} & ODataFunctionOptions<R>): Observable<R | ODataModel<R> | ODataCollection<R, ODataModel<R>> | null>;
    callAction<P, R>(name: string, params: P | null, responseType: 'property' | 'model' | 'collection' | 'none', { ...options }?: {} & ODataActionOptions<R>): Observable<R | ODataModel<R> | ODataCollection<R, ODataModel<R>> | null>;
    private _unlink;
    private _link;
    private _findEntry;
    equals(other: ODataCollection<T, ODataModel<T>>): boolean;
    get [Symbol.toStringTag](): string;
    [Symbol.iterator](): {
        next(): IteratorResult<M>;
    };
    filter(predicate: (value: M, index: number, array: M[]) => unknown, thisArg?: any): M[];
    map<U>(callbackfn: (value: M, index: number, array: M[]) => U, thisArg?: any): U[];
    find(predicate: (value: M, index: number, obj: M[]) => unknown, thisArg?: any): M | undefined;
    reduce<U>(callbackfn: (previousValue: U, currentValue: M, currentIndex: number, array: M[]) => U, initialValue: U): U;
    first(): M | undefined;
    last(): M | undefined;
    next(model: M): M | undefined;
    prev(model: M): M | undefined;
    every(predicate: (m: M, index: number) => boolean): boolean;
    some(predicate: (m: M, index: number) => boolean): boolean;
    contains(model: M): boolean;
    indexOf(model: M): number;
    isEmpty(): boolean;
    private _bisect;
    private _compare;
    _sortBy: {
        field: string | keyof T;
        order?: 1 | -1;
    }[] | null;
    isSorted(): boolean;
    sort(by: {
        field: string | keyof T;
        order?: 1 | -1;
    }[], { silent }?: {
        silent?: boolean;
    }): void;
}
