import type { QueryCustomType, Unpacked } from '../builder';
import { Expression } from './base';
import { FilterExpression, FilterExpressionBuilder } from './filter';
import { OrderByExpression, OrderByExpressionBuilder } from './orderby';
import { SearchExpression, SearchExpressionBuilder } from './search';
import { SelectExpression, SelectExpressionBuilder } from './select';
import { Renderable } from './syntax';
export declare class ExpandField<T> implements Renderable {
    protected field: any;
    private values;
    constructor(field: any, values?: {
        [name: string]: any;
    });
    get [Symbol.toStringTag](): string;
    toJSON(): {
        field: any;
    };
    render({ aliases, escape, prefix, }: {
        aliases?: QueryCustomType[];
        escape?: boolean;
        prefix?: string;
    }): string;
    clone(): ExpandField<T>;
    select<T extends object>(opts: (builder: SelectExpressionBuilder<T>, current?: SelectExpression<T>) => SelectExpression<T>): SelectExpression<T>;
    expand<T extends object>(opts: (builder: ExpandExpressionBuilder<T>, current?: ExpandExpression<T>) => ExpandExpression<T>): ExpandExpression<T>;
    filter<T extends object>(opts: (builder: FilterExpressionBuilder<T>, current?: FilterExpression<T>) => FilterExpression<T>): FilterExpression<T>;
    search<T extends object>(opts: (builder: SearchExpressionBuilder<T>) => SearchExpression<T>): SearchExpression<T>;
    orderBy<T extends object>(opts: (builder: OrderByExpressionBuilder<T>, current?: OrderByExpression<T>) => OrderByExpression<T>): OrderByExpression<T>;
    skip(n: number): number;
    top(n: number): number;
    levels(n: number | 'max'): number | "max";
    count(): boolean;
    private option;
}
export type ExpandExpressionBuilder<T> = {
    t: Readonly<Required<T>>;
    e: () => ExpandExpression<T>;
};
export declare class ExpandExpression<T> extends Expression<T> {
    constructor({ children, }?: {
        children?: Renderable[];
    });
    static expand<T extends object>(opts: (builder: ExpandExpressionBuilder<T>, current?: ExpandExpression<T>) => ExpandExpression<T>, current?: ExpandExpression<T>): ExpandExpression<T>;
    render({ aliases, escape, prefix, }?: {
        aliases?: QueryCustomType[] | undefined;
        escape?: boolean | undefined;
        prefix?: string | undefined;
    }): string;
    clone(): ExpandExpression<T>;
    private _add;
    field<F extends keyof T>(field: T[F], opts?: (e: ExpandField<Unpacked<T[F]>>) => void): ExpandExpression<T>;
}
