import type { QueryCustomType } from '../builder';
import { Expression } from './base';
import { Renderable } from './syntax';
export type SearchConnector = 'AND' | 'OR';
export declare class SearchTerm implements Renderable {
    protected value: string;
    constructor(value: string);
    get [Symbol.toStringTag](): string;
    toJSON(): {
        $type: string;
        value: string;
    };
    render({ aliases, escape, prefix, }: {
        aliases?: QueryCustomType[];
        escape?: boolean;
        prefix?: string;
    }): string;
    clone(): SearchTerm;
}
export type SearchExpressionBuilder<T> = {
    e: (connector?: SearchConnector) => SearchExpression<T>;
};
export declare class SearchExpression<T> extends Expression<T> {
    private _connector;
    private _negated;
    constructor({ children, connector, negated, }?: {
        children?: Renderable[];
        connector?: SearchConnector;
        negated?: boolean;
    });
    static search<T extends object>(opts: (builder: SearchExpressionBuilder<T>, current?: SearchExpression<T>) => SearchExpression<T>, current?: SearchExpression<T>): SearchExpression<T>;
    private _add;
    render({ aliases, escape, prefix, }?: {
        aliases?: QueryCustomType[] | undefined;
        escape?: boolean | undefined;
        prefix?: string | undefined;
    }): string;
    clone(): SearchExpression<T>;
    toJSON(): {
        children: any[];
        connector: SearchConnector;
        negated: boolean;
    };
    connector(): SearchConnector;
    negated(): boolean;
    or(exp: SearchExpression<T>): SearchExpression<T>;
    and(exp: SearchExpression<T>): SearchExpression<T>;
    not(exp: SearchExpression<T>): SearchExpression<T>;
    term(value: any): SearchExpression<T>;
}
