import type { QueryCustomType } from '../builder';
export type Normalize = 'all' | 'right' | 'left' | 'none';
export interface Renderable {
    render({ aliases, escape, prefix, }: {
        aliases?: QueryCustomType[];
        escape?: boolean;
        prefix?: string;
    }): string;
    toString(): string;
    toJSON(): any;
    clone(): any;
}
export declare class Field<T extends object> implements ProxyHandler<T> {
    name: string;
    constructor(name?: string);
    static factory<T extends object>(name?: string): T;
    get(target: T, key: string | symbol): any;
    has(target: T, key: string): any;
}
export declare function render(value: any, { aliases, normalize, escape, prefix, }?: {
    aliases?: QueryCustomType[];
    normalize?: boolean;
    escape?: boolean;
    prefix?: string;
}): string | number | boolean | null;
export declare class Function<T> implements Renderable {
    protected name: string;
    protected values: any[];
    protected normalize: Normalize;
    protected escape: boolean;
    constructor(name: string, values: any[], normalize: Normalize, escape?: boolean);
    get [Symbol.toStringTag](): string;
    toJSON(): {
        $type: string;
        name: string;
        values: any[];
        normalize: Normalize;
    };
    render({ aliases, escape, prefix, }: {
        aliases?: QueryCustomType[];
        escape?: boolean;
        prefix?: string;
    }): string;
    clone(): Function<T>;
}
export declare class StringAndCollectionFunctions<T> {
    concat(left: any, right: any, normalize?: Normalize): Function<T>;
    contains(left: any, right: any, normalize?: Normalize): Function<T>;
    endsWith(left: any, right: any, normalize?: Normalize): Function<T>;
    indexOf(left: any, right: any, normalize?: Normalize): Function<T>;
    length(left: any, normalize?: Normalize): Function<T>;
    startsWith(left: any, right: any, normalize?: Normalize): Function<T>;
    subString(left: any, right: number, length?: number, normalize?: Normalize): Function<T>;
}
export declare class CollectionFunctions<T> {
    hasSubset(left: T, right: any, normalize?: Normalize): Function<T>;
    hasSubsequence(left: T, right: any, normalize?: Normalize): Function<T>;
}
export declare class StringFunctions<T> {
    matchesPattern(left: any | string, pattern: string, normalize?: Normalize): Function<T>;
    toLower(left: any, normalize?: Normalize): Function<T>;
    toUpper(left: any, normalize?: Normalize): Function<T>;
    trim(left: any, normalize?: Normalize): Function<T>;
}
export declare class DateAndTimeFunctions<T> {
    date(left: any, normalize?: Normalize): Function<T>;
    day(left: any, normalize?: Normalize): Function<T>;
    fractionalseconds(left: any, normalize?: Normalize): Function<T>;
    hour(left: any, normalize?: Normalize): Function<T>;
    maxdatetime(left: any, normalize?: Normalize): Function<T>;
    mindatetime(left: any, normalize?: Normalize): Function<T>;
    minute(left: any, normalize?: Normalize): Function<T>;
    month(left: any, normalize?: Normalize): Function<T>;
    now(): Function<T>;
    second(left: any, normalize?: Normalize): Function<T>;
    time(left: any, normalize?: Normalize): Function<T>;
    totaloffsetminutes(left: any, normalize?: Normalize): Function<T>;
    totalseconds(left: any, normalize?: Normalize): Function<T>;
    year(left: any, normalize?: Normalize): Function<T>;
}
export declare class ArithmeticFunctions<T> {
    ceiling(left: T | string, normalize?: Normalize): Function<T>;
    floor(left: T | string, normalize?: Normalize): Function<T>;
    round(left: T | string, normalize?: Normalize): Function<T>;
}
export declare class TypeFunctions<T> {
    cast(left: T | string, right?: string, normalize?: Normalize): Function<T>;
    isof(left: T | string, right?: string, normalize?: Normalize): Function<T>;
}
export declare class GeoFunctions<T> {
    geoDistance(left: T, right: string, normalize?: Normalize): Function<T>;
    geoIntersects(left: T, right: string, normalize?: Normalize): Function<T>;
    geoLength(left: T, normalize?: Normalize): Function<T>;
}
export declare class ConditionalFunctions<T> {
    case(left: T | string, right: any, normalize?: Normalize): Function<T>;
}
export declare class Operator<T> implements Renderable {
    protected op: string;
    protected values: any[];
    protected normalize: Normalize;
    constructor(op: string, values: any[], normalize: Normalize);
    get [Symbol.toStringTag](): string;
    toJSON(): {
        $type: string;
        op: string;
        values: any[];
        normalize: Normalize;
    };
    render({ aliases, escape, prefix, }: {
        aliases?: QueryCustomType[];
        escape?: boolean;
        prefix?: string;
    }): string;
    clone(): Operator<unknown>;
}
export declare class LogicalOperators<T> {
    eq(left: any, right: any, normalize?: Normalize): Operator<unknown>;
    ne(left: any, right: any, normalize?: Normalize): Operator<unknown>;
    gt(left: any, right: any, normalize?: Normalize): Operator<unknown>;
    ge(left: any, right: any, normalize?: Normalize): Operator<unknown>;
    lt(left: any, right: any, normalize?: Normalize): Operator<unknown>;
    le(left: any, right: any, normalize?: Normalize): Operator<unknown>;
    not(left: any, normalize?: Normalize): Operator<T>;
    has(left: any, right: any, normalize?: Normalize): Operator<unknown>;
    in(left: any, right: any, normalize?: Normalize): Operator<unknown>;
}
export declare class ArithmeticOperators<T> {
    add(left: any, right: any, normalize?: Normalize): Operator<T>;
    sub(left: any, right: any, normalize?: Normalize): Operator<unknown>;
    mul(left: any, right: any, normalize?: Normalize): Operator<unknown>;
    div(left: any, right: any, normalize?: Normalize): Operator<unknown>;
    mod(left: any, right: any, normalize?: Normalize): Operator<unknown>;
    neg(value: any, normalize?: Normalize): Operator<unknown>;
}
export declare class Grouping<T> implements Renderable {
    protected group: Renderable;
    constructor(group: Renderable);
    get [Symbol.toStringTag](): string;
    toJSON(): {
        $type: string;
        group: any;
    };
    render({ aliases, escape, prefix, }: {
        aliases?: QueryCustomType[];
        escape?: boolean;
        prefix?: string;
    }): string;
    clone(): Grouping<unknown>;
}
export declare class Lambda<T> implements Renderable {
    protected op: string;
    protected values: any[];
    protected alias?: string | undefined;
    constructor(op: string, values: any[], alias?: string | undefined);
    get [Symbol.toStringTag](): string;
    toJSON(): {
        $type: string;
        op: string;
        values: any[];
        alias: string | undefined;
    };
    render({ aliases, escape, prefix, }: {
        aliases?: QueryCustomType[];
        escape?: boolean;
        prefix?: string;
    }): string;
    clone(): Lambda<unknown>;
}
export declare class LambdaOperators<T> {
    any(left: T, right: any, alias?: string): Lambda<unknown>;
    all(left: T, right: any, alias?: string): Lambda<unknown>;
}
export declare class ODataOperators<T> {
}
export interface ODataOperators<T> extends LogicalOperators<T>, ArithmeticOperators<T>, LambdaOperators<T> {
}
export declare const operators: ODataOperators<any>;
export declare class ODataFunctions<T> {
}
export interface ODataFunctions<T> extends StringAndCollectionFunctions<T>, CollectionFunctions<T>, StringFunctions<T>, DateAndTimeFunctions<T>, ArithmeticFunctions<T>, TypeFunctions<T>, GeoFunctions<T>, ConditionalFunctions<T> {
}
export declare const functions: ODataFunctions<any>;
export declare class ODataSyntax<T> {
}
export interface ODataSyntax<T> extends ODataOperators<T>, ODataFunctions<T> {
}
export declare const syntax: ODataSyntax<any>;
