import { Observable } from 'rxjs';
import { ODataApi } from '../../api';
import { ODataCollection, ODataModel } from '../../models';
import { ODataCallable } from '../../schema/callable';
import { ODataPathSegments } from '../path';
import { ODataQueryOptions } from '../query';
import { ODataResource } from '../resource';
import { ODataEntities, ODataEntity, ODataProperty } from '../responses';
import { ODataEntitiesOptions, ODataEntityOptions, ODataOptions, ODataPropertyOptions } from './options';
export declare class ODataActionResource<P, R> extends ODataResource<R> {
    static factory<P, R>(api: ODataApi, { path, schema, segments, query, }: {
        path?: string;
        schema?: ODataCallable<R>;
        segments?: ODataPathSegments;
        query?: ODataQueryOptions<R>;
    }): ODataActionResource<P, R>;
    static fromResource<P, R>(resource: ODataResource<any>, path: string): ODataActionResource<P, R>;
    clone(): ODataActionResource<P, R>;
    returnType(): string | undefined;
    protected post(params: P | null, options?: ODataEntityOptions & ODataEntitiesOptions & ODataPropertyOptions): Observable<any>;
    /**
     * Execute the action
     * @param params Parameters to be sent to the action
     * @param options Options for the request
     */
    call(params: P | null, options?: ODataEntityOptions): Observable<ODataEntity<R>>;
    call(params: P | null, options?: ODataEntitiesOptions): Observable<ODataEntities<R>>;
    call(params: P | null, options?: ODataPropertyOptions): Observable<ODataProperty<R>>;
    call(params: P | null, options?: {
        alias?: boolean;
        responseType?: 'blob';
    } & ODataOptions): Observable<Blob>;
    call(params: P | null, options?: {
        alias?: boolean;
        responseType?: 'arraybuffer';
    } & ODataOptions): Observable<ArrayBuffer>;
    call(params: P | null, options?: {
        alias?: boolean;
        responseType?: 'none';
    } & ODataOptions): Observable<null>;
    /**
     * Execute the action and return the result as a property
     * @param params Parameters for the action
     * @param options Options for the request
     * @returns Observable of the result of the action
     */
    callProperty(params: P | null, options?: ODataOptions): Observable<R | null>;
    /**
     * Execute the action and return the result as a entity
     * @param params Parameters for the action
     * @param options Options for the request
     * @returns Observable of the result of the action
     */
    callEntity(params: P | null, options?: ODataOptions): Observable<R | null>;
    /**
     * Execute the action and return the result as a model
     * @param params Parameters for the action
     * @param options Options for the request
     * @returns Observable of the result of the action
     */
    callModel<M extends ODataModel<R>>(params: P | null, options?: ODataOptions): Observable<M | null>;
    /**
     * Execute the action and return the result as a entities
     * @param params Parameters for the action
     * @param options Options for the request
     * @returns Observable of the result of the action
     */
    callEntities(params: P | null, options?: ODataOptions): Observable<R[] | null>;
    /**
     * Execute the action and return the result as a collection
     * @param params Parameters for the action
     * @param options Options for the request
     * @returns Observable of the result of the action
     */
    callCollection<M extends ODataModel<R>, C extends ODataCollection<R, M>>(params: P | null, options?: ODataOptions): Observable<C | null>;
    callArraybuffer(params: P | null, { alias, ...options }?: {
        alias?: boolean;
    } & ODataOptions): Observable<ArrayBuffer>;
    callBlob(params: P | null, { alias, ...options }?: {
        alias?: boolean;
    } & ODataOptions): Observable<Blob>;
}
