import { Observable } from 'rxjs';
import { ODataApi } from '../../api';
import { ODataCollection, ODataModel } from '../../models';
import { ODataStructuredType } from '../../schema/structured-type';
import { QueryOption } from '../../types';
import { ODataQueryOptions } from '../query';
import { ODataResource } from '../resource';
import { ODataEntities, ODataEntitiesAnnotations, ODataEntity } from '../responses';
import { ODataActionResource } from './action';
import { ODataCountResource } from './count';
import { ODataEntityResource } from './entity';
import { ODataFunctionResource } from './function';
import { ODataOptions } from './options';
export declare class ODataEntitySetResource<T> extends ODataResource<T> {
    static factory<E>(api: ODataApi, { path, schema, query, }: {
        path: string;
        schema?: ODataStructuredType<E>;
        query?: ODataQueryOptions<E>;
    }): ODataEntitySetResource<E>;
    clone(): ODataEntitySetResource<T>;
    entity(key?: any): ODataEntityResource<T>;
    action<P, R>(path: string): ODataActionResource<P, R>;
    function<P, R>(path: string): ODataFunctionResource<P, R>;
    count(): ODataCountResource<T>;
    cast<C>(type: string): ODataEntitySetResource<C>;
    protected post(attrs: Partial<T>, options?: ODataOptions): Observable<any>;
    protected get(options?: ODataOptions & {
        withCount?: boolean;
        bodyQueryOptions?: QueryOption[];
    }): Observable<any>;
    create(attrs: Partial<T>, options?: ODataOptions): Observable<ODataEntity<T>>;
    fetch(options?: ODataOptions & {
        withCount?: boolean;
        bodyQueryOptions?: QueryOption[];
    }): Observable<ODataEntities<T>>;
    fetchAll(options?: ODataOptions & {
        withCount?: boolean;
        bodyQueryOptions?: QueryOption[];
    }): Observable<{
        entities: T[];
        annots: ODataEntitiesAnnotations<T>;
    }>;
    fetchMany(top: number, options?: ODataOptions & {
        withCount?: boolean;
        bodyQueryOptions?: QueryOption[];
    }): Observable<{
        entities: T[];
        annots: ODataEntitiesAnnotations<T>;
    }>;
    fetchOne(options?: ODataOptions & {
        withCount?: boolean;
        bodyQueryOptions?: QueryOption[];
    }): Observable<{
        entity: T | null;
        annots: ODataEntitiesAnnotations<T>;
    }>;
    fetchEntities(options?: ODataOptions & {
        withCount?: boolean;
        bodyQueryOptions?: QueryOption[];
    }): Observable<T[] | null>;
    fetchCollection<M extends ODataModel<T>, C extends ODataCollection<T, M>>(options?: ODataOptions & {
        withCount?: boolean;
        bodyQueryOptions?: QueryOption[];
    }): Observable<C | null>;
}
