import { Observable } from 'rxjs';
import { ODataApi } from '../../api';
import { ODataCollection, ODataModel } from '../../models';
import { ODataStructuredType } from '../../schema';
import { QueryOption } from '../../types';
import { ODataPathSegments } from '../path';
import { ODataQueryOptions } from '../query';
import { ODataResource } from '../resource';
import { ODataEntities, ODataEntitiesAnnotations, ODataEntity, ODataProperty } from '../responses';
import { ODataEntitiesOptions, ODataEntityOptions, ODataOptions, ODataPropertyOptions } from './options';
import { ODataValueResource } from './value';
export declare class ODataPropertyResource<T> extends ODataResource<T> {
    static factory<P>(api: ODataApi, { path, type, schema, segments, query, }: {
        path: string;
        type?: string;
        schema?: ODataStructuredType<P>;
        segments: ODataPathSegments;
        query?: ODataQueryOptions<P>;
    }): ODataPropertyResource<P>;
    static fromResource<N>(resource: ODataResource<any>, path: string): ODataPropertyResource<N>;
    clone(): ODataPropertyResource<T>;
    key(value: any): ODataPropertyResource<T>;
    keys(values: any[]): ODataPropertyResource<T>;
    value(): ODataValueResource<T>;
    property<P>(path: string): ODataPropertyResource<P>;
    protected get(options?: ODataEntityOptions & ODataEntitiesOptions & ODataPropertyOptions): Observable<any>;
    /**
     * Fetch the property
     * @param options Options for the request
     * @return The entity / entities / property value
     */
    fetch(options?: ODataEntityOptions): Observable<ODataEntity<T>>;
    fetch(options?: ODataEntitiesOptions): Observable<ODataEntities<T>>;
    fetch(options?: ODataPropertyOptions): Observable<ODataProperty<T>>;
    /**
     * Fetch the property value
     * @param options Options for the request
     * @returns The property value
     */
    fetchProperty(options?: ODataOptions): Observable<T | null>;
    /**
     * Fetch the entity
     * @param options Options for the request
     * @returns The entity
     */
    fetchEntity(options?: ODataOptions): Observable<T | null>;
    /**
     * Fetch the entity and return as model
     * @param options Options for the request
     * @returns The model
     */
    fetchModel<M extends ODataModel<T>>(options?: ODataOptions): Observable<M | null>;
    /**
     * Fetch the entities
     * @param options Options for the request
     * @returns The entities
     */
    fetchEntities(options?: ODataOptions & {
        withCount?: boolean;
    }): Observable<T[] | null>;
    /**
     * Fetch the entities and return as collection
     * @param options Options for the request
     * @returns The collection
     */
    fetchCollection<M extends ODataModel<T>, C extends ODataCollection<T, M>>(options?: ODataOptions & {
        withCount?: boolean;
    }): Observable<C | null>;
    fetchOne(options?: ODataOptions & {
        withCount?: boolean;
        bodyQueryOptions?: QueryOption[];
    }): Observable<{
        entity: T | null;
        annots: ODataEntitiesAnnotations<T>;
    }>;
    fetchMany(top: number, options?: ODataOptions & {
        withCount?: boolean;
        bodyQueryOptions?: QueryOption[];
    }): Observable<{
        entities: T[];
        annots: ODataEntitiesAnnotations<T>;
    }>;
    /**
     * Fetch all entities
     * @param options Options for the request
     * @returns All entities
     */
    fetchAll(options?: ODataOptions & {
        withCount?: boolean;
        bodyQueryOptions?: QueryOption[];
    }): Observable<{
        entities: T[];
        annots: ODataEntitiesAnnotations<T>;
    }>;
}
