import { CallableConfig, ParserOptions, Parser } from '../types';
import { ODataSchemaElement } from './element';
import { ODataCallableParser } from './parsers';
import { ODataSchema } from './schema';
export declare class ODataCallable<R> extends ODataSchemaElement {
    entitySetPath?: string;
    bound?: boolean;
    composable?: boolean;
    parser: ODataCallableParser<R>;
    constructor(config: CallableConfig, schema: ODataSchema);
    path(): string;
    configure({ options, parserForType, findOptionsForType, }: {
        options: ParserOptions;
        parserForType: (type: string) => Parser<any>;
        findOptionsForType: (type: string) => any;
    }): void;
    /**
     * Deseialize the given value from the callable.
     * @param value Value to deserialize
     * @param options Options for deserialization
     * @returns Deserialized value
     */
    deserialize(value: any, options?: ParserOptions): any;
    /**
     * Serialize the given value for the callable.
     * @param value Value to serialize
     * @param options Options for serialization
     * @returns Serialized value
     */
    serialize(value: any, options?: ParserOptions): any;
    /**
     * Encode the given value for the callable.
     * @param value Value to encode
     * @param options Options for encoding
     * @returns Encoded value
     */
    encode(value: any, options?: ParserOptions): any;
    /**
     * Returns the binding parameter of the callable.
     * @returns The binding parameter of the callable.
     */
    binding(): import("./parsers").ODataParameterParser<any> | undefined;
}
