import { EnumTypeConfig, Parser, ParserOptions } from '../types';
import { ODataSchemaElement } from './element';
import { ODataEnumTypeFieldParser, ODataEnumTypeParser } from './parsers';
import { ODataSchema } from './schema';
export declare class ODataEnumType<E> extends ODataSchemaElement {
    parser: ODataEnumTypeParser<E>;
    members: {
        [name: string]: E;
    } | {
        [value: number]: string;
    };
    constructor(config: EnumTypeConfig<E>, schema: ODataSchema);
    configure({ options, parserForType, findOptionsForType, }: {
        options: ParserOptions;
        parserForType: (type: string) => Parser<any>;
        findOptionsForType: (type: string) => any;
    }): void;
    /**
     * Returns the fields of the enum type.
     * @returns The fields of the enum type.
     */
    fields(value?: E): ODataEnumTypeFieldParser<E>[];
    /**
     * Find a field by name or value.
     * @param enu The name or value of the field
     * @returns The field with the given name or value
     */
    field(enu: string | E): ODataEnumTypeFieldParser<E>;
    /**
     * Map the fields of the enum type.
     * @param mapper Function that maps the value to the new value
     * @returns The fields mapped by the mapper
     */
    mapFields<T>(mapper: (field: ODataEnumTypeFieldParser<E>) => T): T[];
    /**
     * Deseialize the given value from the enum type.
     * @param value Value to deserialize
     * @param options Options for deserialization
     * @returns Deserialized value
     */
    deserialize(value: any, options?: ParserOptions): E;
    /**
     * Serialize the given value for the enum type.
     * @param value Value to serialize
     * @param options Options for serialization
     * @returns Serialized value
     */
    serialize(value: E, options?: ParserOptions): any;
    /**
     * Encode the given value for the enum type.
     * @param value Value to encode
     * @param options Options for encoding
     * @returns Encoded value
     */
    encode(value: E, options?: ParserOptions): any;
    unpack(value: E): number[];
    pack(value: number[]): E;
}
