import { EnumTypeConfig, EnumTypeFieldConfig, ParserOptions, Parser, FieldParser } from '../../types';
import { ODataAnnotatable } from '../annotation';
export declare class ODataEnumTypeFieldParser<E> extends ODataAnnotatable {
    name: string;
    value: E;
    constructor(name: string, field: EnumTypeFieldConfig<E>);
    titleize(term?: string | RegExp): string;
}
export declare class ODataEnumTypeParser<E> extends ODataAnnotatable implements FieldParser<E> {
    name: string;
    namespace: string;
    alias?: string;
    flags?: boolean;
    members: {
        [name: string]: E;
    } | {
        [value: number]: string;
    };
    private _fields;
    parserOptions?: ParserOptions;
    constructor(config: EnumTypeConfig<E>, namespace: string, alias?: string);
    configure({ options, parserForType, findOptionsForType, }: {
        options: ParserOptions;
        parserForType: (type: string) => Parser<any>;
        findOptionsForType: (type: string) => any;
    }): void;
    isTypeOf(type: string): boolean;
    fields(value?: E): ODataEnumTypeFieldParser<E>[];
    field(nameValue: string | E): ODataEnumTypeFieldParser<E>;
    /**
     * Map the fields of the enum type.
     * @param mapper Function that maps the value to the new value
     * @returns The fields mapped by the mapper
     */
    mapFields<R>(mapper: (field: ODataEnumTypeFieldParser<E>) => R): R[];
    deserialize(value: string, options?: ParserOptions): E;
    serialize(value: E, options?: ParserOptions): string | undefined;
    encode(value: E, options?: ParserOptions): any;
    toJsonSchema(): any;
    validate(member: string | number, { method, navigation, }?: {
        method?: 'create' | 'update' | 'modify';
        navigation?: boolean;
    }): string[] | undefined;
    unpack(value: E): number[];
    pack(value: number[]): E;
}
